Word about ONOS
===============

Open Networking Operating System (ONOS) is a new carrier-grade SDN network
operating system designed for high availability, performance and scale-out with
a mission "to produce the Open Source Network Operating System that will enable
service providers to build real Software Defined Network".

Word about networking-onos
==========================
The "networking-onos" repository contains code which makes the interaction
between ONOS and OpenStack Neutron possible. For more information about ONOS
you can visit  "http://onosproject.org/" and
"https://launchpad.net/neutron" for OpenStack Neutron.

Important Pointers
==================
* You can visit the launchpad page "https://launchpad.net/networking-onos" to get latest project status.
* For any issues or new requirement raise a bug at “https://bugs.launchpad.net/networking-onos”. We will get back.
* Any contribution is appreciated. Let's start contributing.